/* upload widgets */

.progress {
    display: none;
}

.loading .progress {
    display: block;
}

.progress {
    margin-top: 20px;
}

.uploaded-files {
    margin-top: 20px;
    clear: both;
    display: block !important;
}

.uploaded-files .editable {
    height: 30px;
    min-width: 200px;
}

.imagewidget .select-image {
    display: none;
}

.imagewidget.empty .select-image {
    display: inline;
}

.imagewidget .default-image {
    display: none;
}

.imagewidget.empty .default-image {
    display: block;
}

.imagewidget.empty .delete-image, .imagewidget.empty .replace-image {
    display: none;
}

.imagewidget .delete-image:hover {
    text-decoration: none !important;
}

.imagewidget .image-action {
    margin-right: 20px;
}

.fileinput-button:hover {
    color: none !important;
}

/* related widget */
.single .multiple-search {
    display: none;
}

.single.empty .multiple-search {
    display: block;
}

.single.empty .related {
    display: none;
}

/* datetime widget */
.datetime .date, .datetime .time {
    float: left;
}

.datetime .time {
    width: 50px;
}

.datetime .date {
    width: 100px;
}