{% load i18n %}

<div class="control">
    <a data-toggle="modal"
       data-target="#MyModal"
       class="add"
       href="{% url 'haystack_link_popup' %}?callbackOnSelect=parent.djinn.forms.set_link&callbackArgs=tgt:{{ name }}"
       >
      <i class="icon-external-link"></i> {% trans "Select link" %}
    </a>

    <input type="hidden" name="{{ name }}" value="{{ value }}" 
           id="id_{{ name }}" />
    <div id="{{ name }}_link">{{ lexical_value }}</div>
    
</div>
