{% load i18n %}

<div class="control-group datetime {% if not value %}empty{% endif %}">
  <div class="controls">
    <input id="id_{{ name }}_date" 
           class="date" type="text" 
           placeholder="{{ date_hint }}"
           value="{{ date_value }}"
           name="{{ name }}_date">
    <input id="id_{{ name }}_time" 
           class="time" type="text" 
           size="5" placeholder="{{ time_hint }}"
           value="{{ time_value }}"
           name="{{ name }}_time">
  </div>
</div>
